News-Scraper
===

Create a digest of news stories based on provided URLs.

## Installation

1. Download and install [Python 3](https://www.python.org/downloads/)
2. In a terminal, run `pip3 install news_scraper`

#### Update

In a terminal, run `pip3 install news_scraper --upgrade`

## Usage

In a terminal, run `news-scraper`. To see more options, run `news-scraper -h`

#### Supported news sites

NY Daily News, NY Times, DNA Info, SI Advance

## Feedback

[marc@khouri.ca](mailto:marc@khouri.ca)

[Issues and feature requests](https://github.com/mnkhouri/news-scraper/issues)

# Development notes

### Running tests

`tox`

### Deploying a new version to PyPI

`python setup.py sdist upload`
